CORE DEVELOPERS
===============

* Chris Glass (chrisglass)
* Martin Brochhaus

CONTRIBUTORS
============

* Adrien Lemaire
* airtonix
* Audrey Roy
* Benjamin Wohlwend
* Bojan Mihelac
* fivethreeo
* Issac Kelly
* Jacob Rief
* Jonas Obrist
* Justin Steward 
* Kristian Øllegaard
* Martin Ogden
* Mike Yumatov
* Pavel Zhukov
* Raúl Cumplido
* Rolo Mawlabaux

TRANSLATORS
===========

* Pavel Zhukov (Russian)
* Pedro Gracia (Spanish)
